@@ -1,13 +1,14 @@
 package Method::Generate::Constructor;
 
-use strictures 1;
+use Moo::_strictures;
 use Sub::Quote qw(quote_sub unquote_sub quotify);
 use Sub::Defer;
-use Moo::_Utils qw(_getstash);
+use Moo::_Utils qw(_getstash _getglob);
 use Moo;
 
 sub register_attribute_specs {
   my ($self, @new_specs) = @_;
+  $self->assert_constructor;
   my $specs = $self->{attribute_specs}||={};
   while (my ($name, $new_spec) = splice @new_specs, 0, 2) {
     if ($name =~ s/^\+//) {
@@ -74,8 +75,23 @@ sub _build_construction_string {
 
 sub install_delayed {
   my ($self) = @_;
+  $self->assert_constructor;
   my $package = $self->{package};
-  defer_sub "${package}::new" => sub {
+  my (undef, @isa) = @{mro::get_linear_isa($package)};
+  my $isa = join ',', @isa;
+  $self->{deferred_constructor} = defer_sub "${package}::new" => sub {
+    my (undef, @new_isa) = @{mro::get_linear_isa($package)};
+    if (join(',', @new_isa) ne $isa) {
+      my ($expected_new) = grep { *{_getglob($_.'::new')}{CODE} } @isa;
+      my ($found_new) = grep { *{_getglob($_.'::new')}{CODE} } @new_isa;
+      if (($found_new||'') ne ($expected_new||'')) {
+        $found_new ||= 'none';
+        $expected_new ||= 'none';
+        die "Expected parent constructor of $package expected to be"
+        . " $expected_new, but found $found_new: changing the inheritance"
+        . " chain (\@ISA) at runtime is unsupported";
+      }
+    }
     unquote_sub $self->generate_method(
       $package, 'new', $self->{attribute_specs}, { no_install => 1 }
     )
@@ -83,6 +99,27 @@ sub install_delayed {
   $self;
 }
 
+sub current_constructor {
+  my ($self, $package) = @_;
+  return *{_getglob("${package}::new")}{CODE};
+}
+
+sub assert_constructor {
+  my ($self) = @_;
+  my $package = $self->{package} or return 1;
+  my $current = $self->current_constructor($package)
+    or return 1;
+  my $deferred = $self->{deferred_constructor}
+    or die "Unknown constructor for $package already exists";
+  return 1
+    if $deferred == $current;
+  my $current_deferred = (Sub::Defer::defer_info($current)||[])->[3];
+  if ($current_deferred && $current_deferred == $deferred) {
+    die "Constructor for $package has been inlined and cannot be updated";
+  }
+  die "Constructor for $package has been replaced with an unknown sub";
+}
+
 sub generate_method {
   my ($self, $into, $name, $spec, $quote_opts) = @_;
   foreach my $no_init (grep !exists($spec->{$_}{init_arg}), keys %$spec) {
@@ -203,6 +240,7 @@ sub _check_required {
 # bootstrap our own constructor
 sub new {
   my $class = shift;
+  delete _getstash(__PACKAGE__)->{new};
   bless $class->BUILDARGS(@_), $class;
 }
 Moo->_constructor_maker_for(__PACKAGE__)
