@@ -1,12 +1,11 @@
 package Moo::Role;
 
-use strictures 1;
+use Moo::_strictures;
 use Moo::_Utils;
 use Role::Tiny ();
 our @ISA = qw(Role::Tiny);
-use Import::Into;
 
-our $VERSION = '1.006001';
+our $VERSION = '2.000000';
 $VERSION = eval $VERSION;
 
 require Moo::sification;
@@ -31,8 +30,10 @@ sub _install_tracked {
 sub import {
   my $target = caller;
   my ($me) = @_;
+
   _set_loaded(caller);
-  strictures->import::into(1);
+  strict->import;
+  warnings->import;
   if ($Moo::MAKERS{$target} and $Moo::MAKERS{$target}{is_class}) {
     die "Cannot import Moo::Role into a Moo class";
   }
@@ -388,15 +389,24 @@ sub _handle_constructor {
   my ($me, $to, $role) = @_;
   my $attr_info = $INFO{$role} && $INFO{$role}{attributes};
   return unless $attr_info && @$attr_info;
-  if ($INFO{$to}) {
-    push @{$INFO{$to}{attributes}||=[]}, @$attr_info;
-  } else {
-    # only fiddle with the constructor if the target is a Moo class
-    if ($INC{"Moo.pm"}
-        and my $con = Moo->_constructor_maker_for($to)) {
-      # shallow copy of the specs since the constructor will assign an index
-      $con->register_attribute_specs(map ref() ? { %$_ } : $_, @$attr_info);
-    }
+  my $info = $INFO{$to};
+  my $con = $INC{"Moo.pm"} && Moo->_constructor_maker_for($to);
+  my %existing
+    = $info ? @{$info->{attributes} || []}
+    : $con  ? %{$con->all_attribute_specs || {}}
+    : ();
+
+  my @attr_info =
+    map { @{$attr_info}[$_, $_+1] }
+    grep { ! $existing{$attr_info->[$_]} }
+    map { 2 * $_ } 0..@$attr_info/2-1;
+
+  if ($info) {
+    push @{$info->{attributes}||=[]}, @attr_info;
+  }
+  elsif ($con) {
+    # shallow copy of the specs since the constructor will assign an index
+    $con->register_attribute_specs(map ref() ? { %$_ } : $_, @attr_info);
   }
 }
 
@@ -412,6 +422,7 @@ Moo::Role - Minimal Object Orientation support for Roles
  package My::Role;
 
  use Moo::Role;
+ use strictures 2;
 
  sub foo { ... }
 
@@ -428,6 +439,7 @@ And elsewhere:
  package Some::Class;
 
  use Moo;
+ use strictures 2;
 
  # bar gets imported, but not foo
  with('My::Role');
